C
C------------------------------------------------------
C
C     Problem:    DIALYSI4
C
C     Date:       9.7.1997
C
C------------------------------------------------------
C
*     REAL CONSTANT
      C01 = 0.19409
      C02 = 0.19404
      C03 = 0.19404
      VD  = 252  
      VA  = 251000
      F   = 254
C
C------------------------------------------------------
C
C   - Independent variables in the following order:
C     1. parameters to be estimated (p)
C     2. variables identifying solution of partial
C        differential equations (u)
C     3. variables identifying first space derivatives of
C        solution of partial differential equations (ux)
C     4. variables identifying second space derivatives of
C        solution of partial differential equations (uxx)
C     5. variables identifying solution of coupled
C        ordinary differential equations (v)
C     6. space variable (x)
C     7. time variable (t)
C
*     VARIABLE
      D1, D2, k1, k2, k3, L1, L2, L3
      u1, u2, u3, u1_x, u2_x, u3_x, u1_xx, u2_xx, u3_xx
      q1, q2, q3, x, t
C
C------------------------------------------------------
C
C   - Functions defining right-hand side of system of 
C     partial differential equations (order: functions in
C     first area, functions in second area, etc.):
C
*     FUNCTION u11_p
      u11_p = D1*u1_xx
C
*     FUNCTION u12_p
      u12_p = D1*u2_xx
C
*     FUNCTION u13_p
      u13_p = D1*u3_xx
C
*     FUNCTION u21_p
      u21_p = D2/L1**2*u1_xx
C
*     FUNCTION u22_p
      u22_p = D2/L2**2*u2_xx
C
*     FUNCTION u23_p
      u23_p = D2/L3**2*u3_xx
C
C------------------------------------------------------
C
C   - Initial values of system of partial differential
C     equations for t=0 (order: functions in
C     first area, functions in second area, etc.):
C
*     FUNCTION u11_0
      u11_0 = C01
C
*     FUNCTION u12_0
      u12_0 = C02
C
*     FUNCTION u13_0
      u13_0 = C03
C
*     FUNCTION u21_0
      u21_0 = 0
C
*     FUNCTION u22_0
      u22_0 = 0
C
*     FUNCTION u23_0
      u23_0 = 0
C
C------------------------------------------------------
C
C   - Functions defining right-hand side of system of 
C     coupled ordinary differential equations:
C
*     FUNCTION q1_p
      q1_p = -D2*F/L1*u1_x
C
*     FUNCTION q2_p
      q2_p = -D2*F/L2*u2_x
C
*     FUNCTION q3_p
      q3_p = -D2*F/L3*u3_x
C
C------------------------------------------------------
C
C   - Initial values of system of coupled ordinary
C     differential equations for t=0: 
C
*     FUNCTION q1_0
      q1_0 = 0
C
*     FUNCTION q2_0
      q2_0 = 0
C
*     FUNCTION q3_0
      q3_0 = 0
C
C------------------------------------------------------
C
C   - Boundary and transition functions first at left
C     borders of all areas, then at right borders of all 
C     areas:
C
*     FUNCTION u21_left
      u21_left = k1*u1
C
*     FUNCTION u22_left
      u22_left = k2*u2
C
*     FUNCTION u23_left
      u23_left = k3*u3
C
*     FUNCTION u21_right
      u21_right = k1*q1/VA
C
*     FUNCTION u22_right
      u22_right = k2*q2/VA
C
*     FUNCTION u23_right
      u23_right = k3*q3/VA
C
C------------------------------------------------------
C
C   - Boundary and transition gradients first at left
C     borders of all areas, then at right borders of all 
C     areas:
C
*     FUNCTION u11_x_left
      u11_x_left = 0
C
*     FUNCTION u12_x_left
      u12_x_left = 0
C
*     FUNCTION u13_x_left
      u13_x_left = 0
C
*     FUNCTION u11_x_right
      u11_x_right = D2/D1*u1_x/L1 
C
*     FUNCTION u12_x_right
      u12_x_right = D2/D1*u2_x/L2 
C
*     FUNCTION u13_x_right
      u13_x_right = D2/D1*u3_x/L3 
C
C------------------------------------------------------
C
C   - Fitting criteria:
C
*     FUNCTION fit1
      fit1 = q1
C
*     FUNCTION fit2
      fit2 = q2
C
*     FUNCTION fit3
      fit3 = q3
C
C------------------------------------------------------
C
*     END
C
C------------------------------------------------------
C
