C
C------------------------------------------------------
C
C     Problem:    HYDRO_2C
C
C     Date:       07.12.2000
C
C------------------------------------------------------
C
*     SET OF INDICES
      ind = 1..20
C
C------------------------------------------------------
C
*     REAL CONSTANT
      b      = 5
      g      = 9.81
      beta   = 1
      c      = 0.01
      w      = 0.0001
      Q0     = 1.65
      H0     = 1.2
      alpha  = 2
      Hd     = 0.5
      Hgoal1 = 1
      Hgoal2 = 0.9
C
C------------------------------------------------------
C
*     LININT input
         0.0    1.65
        20.0    50.0
        80.0    1.65 
       500.0    0.0
C
C------------------------------------------------------
C
*     MACRO u1
      s = 0.001
      u1 = u11 + u12*(s*t) + u13*(s*t)**2 
C
*     MACRO u2
      s  =0.001
      u2 = u21 + u22*(s*t) + u23*(s*t)**2 
C
C------------------------------------------------------
C
C   - Independent variables in the following order:
C     1. parameters to be estimated (p)
C     2. variables identifying solution of partial
C        differential equations, first the differential ones,
C        then the algebraic variables (u)
C     3. variables identifying first spatial derivatives of
C        solution of partial differential equations (u_x)
C     4. variables identifying second spatial derivatives of
C        solution of partial differential equations (u_xx)
C     5. variables identifying solution of coupled
C        ordinary differential equations (v)
C     6. variables for flux functions, if available (one
C        variable for each function (f), then one for
C        each derivative (f_x). These names can be
C        inserted subsequently. Note that flux variables
C        must be declared for each PDE equation, if at all.
C     7. spatial variable (x)
C     8. time variable (t)
C
*     VARIABLE
      u11, u12, u13, u21, u22, u23
      Q, H, Q_x, H_x, Q_xx, H_xx
      fQ, fH, fQ_x, fH_x, x, t
C
C------------------------------------------------------
C
C   - Functions defining the flux depending on u and u_x,
C     if available (order: functions in first area, func-
C     tions in second area, etc.):
C
*     FUNCTION flux1_Q
      if (H.lt.1.0E-5) then
        term = 0
      else
        term = beta/b*Q**2/H
      endif
      flux1_Q = -g*b*H**2/2  - term
C
*     FUNCTION flux1_H
      flux1_H = -Q/b
C
*     FUNCTION flux2_Q
      if (H.lt.1.0E-5) then
        term = 0
      else
        term = beta/b*Q**2/H
      endif
      flux2_Q = -g*b*H**2/2  - term
C
*     FUNCTION flux2_H
      flux2_H = -Q/b
C
C------------------------------------------------------
C
C   - Functions defining right-hand side of system of 
C     partial differential equations (order: differential
C     followed by algebraic functions in first area, then
C     differential followed by algebraic functions in 
C     second area, etc.):
C
*     FUNCTION Q1_t
      if (H.lt.1.0E-5) then
        S = 0
      else
        A = b*H
        R = A/(b + 2*H)
        S = c**2*abs(Q)*Q/(R**(4/3)*A**2) - w
      endif
      Q1_t = -g*b*H*S + fQ_x
C
*     FUNCTION H1_t
      H1_t = fH_x
C
*     FUNCTION Q2_t
      if (H.lt.1.0E-5) then
        S = 0
      else
        A = b*H
        R = A/(b + 2*H)
        S = c**2*abs(Q)*Q/(R**(4/3)*A**2) - w
      endif
      Q2_t = -g*b*H*S + fQ_x
C
*     FUNCTION H2_t
      H2_t = fH_x
C
C------------------------------------------------------
C
C   - Initial values of system of partial differential
C     equations for t=0 (order: initial values for 
C     differential followed by algebraic variables in 
C     first area, then differential followed by algebraic
C     variables in second area, etc.):
C
*     FUNCTION Q1_0
      Q1_0 = Q0
C
*     FUNCTION H1_0
      H1_0 = H0      
C
*     FUNCTION Q2_0
      Q2_0 = Q0
C
*     FUNCTION H2_0
      H2_0 = H0      
C
C------------------------------------------------------
C
C   - Functions defining right-hand side of system of 
C     coupled ordinary differential equations, order 
C     defined by increasing spatial positions:
C
c*     FUNCTION equ
c      equ =  ...
C
C------------------------------------------------------
C
C   - Initial values of system of coupled ordinary
C     differential equations for t=0 in the same order: 
C
c*     FUNCTION v_0
c      v_0 = ...
C
C------------------------------------------------------
C
C   - Boundary and transition functions first at left
C     border of an area, then at right border of an
C     area, etc.:
C
*     FUNCTION Q1_left
      Q1_left = input(t)
C
*     FUNCTION Q1_right
      Q1_right = Q
C
*     FUNCTION H2_left
      if (u1.ne.0) then
        H2_left = -(Q/(alpha*u1))**2/g + H
      else
        H2_left = 0
      endif
C
*     FUNCTION H2_right
      if (u2.ne.0) then
        H2_right = (Q/(alpha*u2))**2/g + Hd
      else
        H2_right = 0
      endif
C
C------------------------------------------------------
C
C   - Boundary and transition gradients w.r.t. spatial 
C     variable first at left border of an area, then
C     at right border of an areas, etc.:
C
C*     FUNCTION u_x_left
C      u_x_left = ...
C
C------------------------------------------------------
C
C   - Fitting criteria, order defined by increasing 
C     spatial positions:
C
*     FUNCTION fit_H(i), i in ind
      if (x.lt.500) then
        fit_H(i) = H - Hgoal1
      else
        fit_H(i) = H - Hgoal2
      endif
C
C------------------------------------------------------
C
C   - Constraints (if exist):
C
C*     FUNCTION g1
C      g1 = ...
C
C------------------------------------------------------
C
*     END
C
C------------------------------------------------------
C




